@@ -1,7 +1,4 @@
-##' @include games.r
-##' @include helpers.r
-NULL
-
+##' @export
 predict.egame122 <- function(object, newdata, type = c("outcome", "action"),
                              na.action = na.pass, ...)
 {
@@ -265,7 +262,7 @@ makeResponse122 <- function(yf)
             Y <- Y[, 1:3]
         }
 
-        if (!identical(sort(unique(unlist(Y))), c(0, 1)))
+        if (!all(unlist(Y) %in% c(0L, 1L)))
             stop("dummy responses must be dummy variables")
 
         if (ncol(Y) == 3) {
@@ -375,31 +372,7 @@ makeResponse122 <- function(yf)
 ##' @export
 ##' @author Brenton Kenkel (\email{brenton.kenkel@@gmail.com}) and Curtis
 ##' S. Signorino
-##' @examples
-##' data(data_122)
-##'
-##' ## the formula:
-##' fr1 <- y ~ x1 + x2 | x3 + f1 | 0 | x4 + x5 | z1 + z2 | z3 + f2
-##' ##     ^   ^^^^^^^   ^^^^^^^   ^   ^^^^^^^   ^^^^^^^   ^^^^^^^
-##' ##     y     u11       u12    u13    u14       u22       u24
-##'
-##' m1 <- egame122(fr1, data = data_122)
-##' summary(m1)
-##'
-##' ## dummy specification of the dependent variable
-##' fr2 <- update(Formula(fr1), a1 + a2 ~ .)
-##' m2 <- egame122(fr2, data = data_122)
-##' summary(m2)
-##'
-##' ## estimation of scale parameters
-##' fr3 <- y ~ x1 | x2 | 0 | x3 | z1 | z2
-##' m3 <- egame122(fr3, data = data_122, sdformula = ~ x4 + z3 - 1)
-##' summary(m3)
-##'
-##' ## fixed utilities
-##' utils <- c(0.25, -0.25, 0, 0.25, 0.5, -0.5)
-##' m4 <- egame122(y ~ 1, data = data_122, fixedUtils = utils)
-##' summary(m4)
+##' @example inst/examples/egame122.r
 egame122 <- function(formulas, data, subset, na.action,
                      link = c("probit", "logit"),
                      type = c("agent", "private"),
