@@ -1,7 +1,4 @@
-##' @include games.r
-##' @include helpers.r
-NULL
-
+##' @export
 predict.egame123 <- function(object, newdata, type = c("outcome", "action"),
                              na.action = na.pass, ...)
 {
@@ -396,21 +393,7 @@ makeResponse123 <- function(yf)
 ##' \code{\link{egame12}} for a description of the \code{game} class.
 ##' @export
 ##' @author Brenton Kenkel (\email{brenton.kenkel@@gmail.com})
-##' @examples
-##' data(data_123)
-##'
-##' ## the formula:
-##' f1 <- y ~ x1 + x2 | 0 | x3 | x4 + x5 | 0 | x6 | x7 | x8
-##' ##    ^   ^^^^^^^   ^   ^^   ^^^^^^^   ^   ^^   ^^   ^^
-##' ##    y     u11    u13  u15    u16    u23  u25  u26  u36
-##' 
-##' m1 <- egame123(f1, data = data_123, link = "probit", type = "private")
-##' summary(m1)
-##'
-##' ## dummy specification of the dependent variable
-##' f2 <- update(Formula(f1), a1 + a2 + a3 ~ .)
-##' m2 <- egame123(f2, data = data_123, link = "probit", type = "private")
-##' summary(m2)
+##' @example inst/examples/egame123.r
 egame123 <- function(formulas, data, subset, na.action,
                      link = c("probit", "logit"),
                      type = c("agent", "private"),
