@@ -1,7 +1,3 @@
-##' @include games.r
-##' @include helpers.r
-NULL
-
 ##' Model formula construction
 ##' 
 ##' Interactive prompt for constructing model formulas.
@@ -65,87 +61,7 @@ NULL
 ##' the details of how \pkg{games} deals with multiple model formulas.
 ##' @export
 ##' @author Brenton Kenkel (\email{brenton.kenkel@@gmail.com})
-##' @examples
-##' \dontrun{R> f1 <- makeFormulas(egame122, outcomes = c("budget cuts passed",
-##' "budget cuts vetoed", "budget increase passed", "budget increase vetoed"))
-##'
-##' ---
-##' Equation for player 1's utility from budget cuts passed: 
-##'
-##' 1: fix to 0
-##' 2: intercept only
-##' 3: regressors, no intercept
-##' 4: regressors with intercept
-##'
-##' Selection: 4
-##'
-##' Enter variable names (separated by spaces):
-##' legparty growth
-##'
-##' ---
-##' Equation for player 1's utility from budget cuts vetoed: 
-##'
-##' 1: fix to 0
-##' 2: intercept only
-##' 3: regressors, no intercept
-##' 4: regressors with intercept
-##'
-##' Selection: 2
-##'
-##' ---
-##' Equation for player 1's utility from budget increase passed: 
-##'
-##' 1: fix to 0
-##' 2: intercept only
-##' 3: regressors, no intercept
-##' 4: regressors with intercept
-##'
-##' Selection: 4
-##'
-##' Enter variable names (separated by spaces):
-##' legparty growth
-##'
-##' ---
-##' Equation for player 1's utility from budget increase vetoed: 
-##'
-##' 1: fix to 0
-##' 2: regressors, no intercept
-##'
-##' Selection: 1
-##'
-##' ---
-##' Equation for player 2's utility from budget cuts vetoed: 
-##'
-##' 1: fix to 0
-##' 2: intercept only
-##' 3: regressors, no intercept
-##' 4: regressors with intercept
-##'
-##' Selection: 4
-##'
-##' Enter variable names (separated by spaces):
-##' presparty growth
-##'
-##' ---
-##' Equation for player 2's utility from budget increase vetoed: 
-##'
-##' 1: fix to 0
-##' 2: intercept only
-##' 3: regressors, no intercept
-##' 4: regressors with intercept
-##'
-##' Selection: 4
-##'
-##' Enter variable names (separated by spaces):
-##' presparty growth
-##'
-##' ---
-##' What is the name of the dependent variable in the dataset? (If stored as
-##' action indicators/dummies, separate their names with spaces.)
-##' budgincrease veto
-##' R> f1
-##' budgincrease + veto ~ legparty + growth | 1 | legparty + growth | 
-##'     0 | presparty + growth | presparty + growth}
+##' @example inst/examples/makeFormulas.r
 makeFormulas <- function(model, outcomes)
 {
     ## convert 'model' to character if supplied without quotation marks
